===================================
OpenStack Swift Administrator Guide
===================================

.. toctree::
   :maxdepth: 2

   objectstorage-intro.rst
   objectstorage-features.rst
   objectstorage-characteristics.rst
   objectstorage-components.rst
   objectstorage-ringbuilder.rst
   objectstorage-arch.rst
   objectstorage-replication.rst
   objectstorage-large-objects.rst
   objectstorage-auditors.rst
   objectstorage-EC.rst
   objectstorage-account-reaper.rst
   objectstorage-tenant-specific-image-storage.rst
   objectstorage-monitoring.rst
   objectstorage-troubleshoot.rst
